about summary refs log tree commit diff
path: root/src/liballoc/sync.rs
diff options
context:
space:
mode:
authorljedrz <ljedrz@gmail.com>2018-07-11 10:19:54 +0200
committerljedrz <ljedrz@gmail.com>2018-07-11 10:19:54 +0200
commit217f8fbd4512ebe94fb021ee564ea6c6dae6a919 (patch)
tree3287c0e80c7f60c13d56be5b2212e15de863c632 /src/liballoc/sync.rs
parentcd44b3ddaddf22ef3c3b00f31491c660b851f8ee (diff)
downloadrust-217f8fbd4512ebe94fb021ee564ea6c6dae6a919.tar.gz
rust-217f8fbd4512ebe94fb021ee564ea6c6dae6a919.zip
Revert borked changes in last commit.
Diffstat (limited to 'src/liballoc/sync.rs')
-rw-r--r--src/liballoc/sync.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/liballoc/sync.rs b/src/liballoc/sync.rs
index 35aae191683..5def0237e7e 100644
--- a/src/liballoc/sync.rs
+++ b/src/liballoc/sync.rs
@@ -978,10 +978,10 @@ unsafe impl<#[may_dangle] T: ?Sized> Drop for Arc<T> {
     }
 }
 
-impl Arc<Any + Send + Sync> {
+impl Arc<dyn Any + Send + Sync> {
     #[inline]
     #[stable(feature = "rc_downcast", since = "1.29.0")]
     /// Attempt to downcast the `Arc<Any + Send + Sync>` to a concrete type.
     ///
     /// # Examples
     ///
@@ -989,7 +989,7 @@ impl Arc<Any + Send + Sync> {
     /// use std::any::Any;
     /// use std::sync::Arc;
     ///
-    /// fn print_if_string(value: Arc<Any + Send + Sync>) {
+    /// fn print_if_string(value: Arc<dyn Any + Send + Sync>) {
     ///     if let Ok(string) = value.downcast::<String>() {
     ///         println!("String ({}): {}", string.len(), string);
     ///     }
@@ -978,10 +978,10 @@ unsafe impl<#[may_dangle] T: ?Sized> Drop for Arc<T> {
     #[inline]
     #[stable(feature = "rc_downcast", since = "1.29.0")]
-    /// Attempt to downcast the `Arc<Any + Send + Sync>` to a concrete type.
+    /// Attempt to downcast the `Arc<dyn Any + Send + Sync>` to a concrete type.
     ///
     /// # Examples